@ECHO OFF

REM Define user name that will be used if you decide to submit results
SET "user_name=anonymous"

SET "script=NV Bench 1.1"
SET "name=NeatVideo Results Database"

SET "neatbench=NeatBench5.exe"
SET "curl=cURL.exe"

SET "url=http://fifonik.com/nv/"
SET "add_path=add.json"


SET "DEBUG="


REM *********************************************************************************
REM YOU'D BETTER DO NOT CHANGE ANYTHING BELOW UNTIL YOU UNDERSTAND WHAT ARE YOU DOING

ECHO +------------------------------------------------------------------------------+
ECHO !  %script%                                                                !
ECHO !                                                                              !
ECHO !  Script runs %neatbench% with different parameters                        !
ECHO !                                                                              !
ECHO !  If %curl% found, the script will be able to submit results to             !
ECHO !  %name% ^<%url%^>                         !
ECHO !  Note: it will NOT send anything until you allow script to do this.          !
ECHO !                                                                              !
ECHO !  Hint: Press Ctrl+C any time to stop.                                        !
ECHO +------------------------------------------------------------------------------+
ECHO.

IF NOT [%DEBUG%]==[] ECHO Getting system info...
CALL :get_wmic_value cpu CPU Name
CALL :get_wmic_value gpus "PATH Win32_VideoController" Name
CALL :get_wmic_value os_caption OS Caption
CALL :get_wmic_value os_version OS Version
CALL :get_wmic_value os_architecture OS OSArchitecture

SET os_name=%os_caption:Microsoft =%

ECHO OS:     %os_name% ^(%os_architecture%^) %os_version%
ECHO CPU:    %cpu%
ECHO GPU(s): %gpus%
ECHO.

CALL :whereis filespec %neatbench%
IF ["%filespec%"]==[""] (
	ECHO %neatbench%: NOT FOUND in script's dir or system %%PATH%%. Stopped
	GOTO :eof
) ELSE (
	ECHO %neatbench%: found ^(%filespec%^)
)

CALL :whereis filespec %curl%
IF ["%filespec%"]==[""] (
	ECHO %curl%:       NOT FOUND in script's dir or system %%PATH%%.
	ECHO Script UNABLE to submit results to %name%
	ECHO If you would like to submit results you should:
	ECHO 1. Download curl for windows from the project web-site: https://curl.haxx.se/windows/
	ECHO 2. Unpack and put curl executable aside of the script
	GOTO :start
) ELSE (
	ECHO %curl%:       found ^(%filespec%^)
)

ECHO.
ECHO Would you like to submit results with the sysinfo as '%user_name%' to
SET /P "yn=%name%? [Y/N] "
IF [%yn%]==[y] SET "send=1"
IF [%yn%]==[Y] SET "send=1"
IF [%send%]==[1] (
	ECHO Results will be submitted to %name%
) ELSE (
	ECHO Results will NOT be submitted to %name%
)


:start
ECHO.
ECHO.
ECHO PROCESS STARTED. Hold on, this might take a few minutes to complete...

SET "radiuses=0 1 2 3 4 5"
SET "bitdepths=8 32"

FOR %%b IN (%bitdepths%) DO (
	FOR %%r IN (%radiuses%) DO CALL :exec %%r %%b
)

DEL /Q "%USERPROFILE%\NeatBenchLog*"  >nul 2>&1

ECHO.
ECHO PROCESS FINISHED

IF [%send%]==[1] (
	ECHO.
	ECHO Many thanks for submitting results to %name%
)
GOTO :eof


:exec
ECHO.
CALL :bench %1 %2 filename
ECHO File %filename% created successfully
IF [%send%]==[1] (
	CALL :send "%filename%" "%sysinfo%"
)
GOTO :eof


:bench
SETLOCAL
SET "frame=1920x1080"
SET "type=P"
SET "radius=%1"
SET "bitdepth=%2"
SET "filename=NeatBench_%frame%%type%_%bitdepth%_%radius%.txt"

ECHO Executing %neatbench% with frame=%frame%%type%, bitdepth=%bitdepth%, radius=%radius%
SET "command=%neatbench% %frame% %radius% %type% %bitdepth% nowait"
IF NOT [%DEBUG%]==[] ECHO ^> %command% ^> %filename%
%command% >%filename% 2>&1
ENDLOCAL & SET "%3=%filename%" & EXIT /B
GOTO :eof


:send
SET "filespec=%~1"
SET "outfile=stdout.txt"
SET "errfile=stderr.txt"

ECHO Sending results to NeatVideo Results Database
SET command=%curl% --silent --fail --show-error --data-urlencode "name=%user_name%" --data-urlencode "script=%script%" --data-urlencode "os=%os_name% (%os_architecture%) %os_version%" --data-urlencode "cpu=%cpu%" --data-urlencode "gpu=%gpus%" --data-urlencode "log@%filespec%" %url%%add_path%

IF NOT [%DEBUG%]==[] ECHO ^> %command%

%command% 1> "%outfile%" 2> "%errfile%"

IF [%ERRORLEVEL%]==[0] (
	ECHO OK
) ELSE (
	ECHO FAIL
	TYPE %errfile%
)

IF [%DEBUG%]==[] (
	DEL /Q %outfile% >nul 2>&1
	DEL /Q %errfile% >nul 2>&1
)
ECHO.

GOTO :eof


:whereis
SETLOCAL
SET "r=%~dp0%~2"
IF NOT EXIST "%r%" CALL :find_in_path r "%~2"
ENDLOCAL & SET "%1=%r%" & EXIT /B
GOTO :eof


:find_in_path
SETLOCAL
REM Based on "FOR /?" and https://devblogs.microsoft.com/oldnewthing/20050120-00/?p=102308
FOR %%x IN (%~2) DO SET "r=%%~$PATH:x"
ENDLOCAL & SET "%1=%r%" & EXIT /B
GOTO :eof



:get_wmic_value
SETLOCAL
REM ECHO %1 %2 %3
SET "sections=%~2"
SET "name=%~3"
SET "command=wmic %sections% get %name%"
SET "r="
FOR /F "tokens=* skip=1" %%n IN ('%command% ^| findstr "."') DO CALL :append r "%%n" ","
ENDLOCAL & SET "%1=%r%" & EXIT /B
GOTO :eof


:append
SETLOCAL EnableDelayedExpansion
REM ECHO %1 %2 %3
CALL :trim v %~2
REM ECHO "!%1!" "%v%"
IF ["!%1!"]==[""] (
	SET "r=%v%"
) ELSE (
	SET "r=!%1!%~3%v%"
)
ENDLOCAL & SET "%1=%r%" & EXIT /B
GOTO :eof


:trim
SETLOCAL EnableDelayedExpansion
SET params=%*
FOR /F "tokens=1*" %%a IN ("!params!") DO ENDLOCAL & SET "%1=%%b"
EXIT /B
GOTO :eof


